@@ -1014,6 +1014,9 @@ extern struct samd21_tcc samd21_tcc3;
 #define SAMD21_TCC_SYNCBUSY_PERB	18
 #define SAMD21_TCC_SYNCBUSY_CCB(x)	((19 + (x))
 
+#define SAMD21_TCC_DBGCTRL_FDDBD	2
+#define SAMD21_TCC_DBGCTRL_DBGRUN	0
+
 #define SAMD21_TCC_EVCTRL_EVACTO	0
 #define SAMD21_TCC_EVCTRL_EVACT1	3
 #define SAMD21_TCC_EVCTRL_CNTSEL	6
